/*
   jcl.c - test if input line looks like Job Control Language (JCL)

   Author: Paul Hardy, August 2020

   Copyright (C) 2020 Paul Hardy

   LICENSE:

      This program is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
      the Free Software Foundation, either version 2 of the License, or
      (at your option) any later version.

      This program is distributed in the hope that it will be useful,
      but WITHOUT ANY WARRANTY; without even the implied warranty of
      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
      GNU General Public License for more details.

      You should have received a copy of the GNU General Public License
      along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/*
   jcl - return:

        1 if a JCL or comment line
        0 if a FORTRAN non-comment program line
*/
int
jcl (char *inbuffer) {
   int i;       /* loop variable */
   int retval;  /* return value  */

   /*
      A FORTRAN IV program line can contain one optional
      line number, optionally preceded or followed by spaces.
      Treat anything else as not constituting a FORTRAN
      program line, either being a comment line or JCL.
      IBM JCL begins a line with a '/' character.
      CDC JCL contains alphabetic and other non-decimal
      digit characters in the first five columns.  This
      function should therefore correctly identify both
      IBM and CDC JCL.
   */
   i = 0;
   while (i < 5 && inbuffer[i] == ' ')    i++;
   while (i < 5 && isdigit (inbuffer[i])) i++;
   while (i < 5 && inbuffer[i] == ' ')    i++;

   if (i == 5)
      retval = 0;
   else
      retval = 1;

   return retval;
}

